@@ -12,10 +12,10 @@ cleanup() {
 
 trap "cleanup" INT TERM EXIT
 
-if [ "${TRAVIS_PYTHON_VERSION}" = "3.5" ]; then
+if [ "${DEPLOY_ENV}" = "true" ]; then
    # full
    # Run tests with "python -m pytest" to use the correct version of pytest
-   echo -e "\n\n****** Running tests ******\n\n"
+   echo -e "\n\n****** Running tests with coverage ******\n\n"
    coverage run --source odsclient -m pytest --junitxml=reports/junit/junit.xml --html=reports/junit/report.html -s -v odsclient/  # and not odsclient/tests/: we want DocTest too
    # buggy
    # python -m pytest --junitxml=reports/junit/junit.xml --html=reports/junit/report.html --cov-report term-missing --cov=./odsclient -v odsclient/tests/
